@@ -107,7 +107,7 @@ import           Linear.Vector
 --
 --   The idea for envelopes came from
 --   Sebastian Setzer; see
---   <http://byorgey.wordpress.com/2009/10/28/collecting-attributes/#comment-2030>.  See also Brent Yorgey, /Monoids: Theme and Variations/, published in the 2012 Haskell Symposium: <http://www.cis.upenn.edu/~byorgey/pub/monoid-pearl.pdf>; video: <http://www.youtube.com/watch?v=X-8NCkD2vOw>.
+--   <http://byorgey.wordpress.com/2009/10/28/collecting-attributes/#comment-2030>.  See also Brent Yorgey, /Monoids: Theme and Variations/, published in the 2012 Haskell Symposium: <http://ozark.hendrix.edu/~yorgey/pub/monoid-pearl.pdf>; video: <http://www.youtube.com/watch?v=X-8NCkD2vOw>.
 newtype Envelope v n = Envelope (Option (v n -> Max n))
 
 instance Wrapped (Envelope v n) where
@@ -116,16 +116,24 @@ instance Wrapped (Envelope v n) where
 
 instance Rewrapped (Envelope v n) (Envelope v' n')
 
+-- | \"Apply\" an envelope by turning it into a function.  @Nothing@
+--   is returned iff the envelope is empty.
 appEnvelope :: Envelope v n -> Maybe (v n -> n)
 appEnvelope (Envelope (Option e)) = (getMax .) <$> e
 
+-- | A convenient way to transform an envelope, by specifying a
+--   transformation on the underlying @v n -> n@ function.  The empty
+--   envelope is unaffected.
 onEnvelope :: ((v n -> n) -> v n -> n) -> Envelope v n -> Envelope v n
 onEnvelope t = over (_Wrapping' Envelope . mapped) ((Max .) . t . (getMax .))
 
+-- | Create an envelope from a @v n -> n@ function.
 mkEnvelope :: (v n -> n) -> Envelope v n
 mkEnvelope = Envelope . Option . Just . (Max .)
 
--- | Create an envelope for the given point.
+-- | Create a point envelope for the given point.  A point envelope
+--   has distance zero to a bounding hyperplane in every direction.
+--   Note this is /not/ the same as the empty envelope.
 pointEnvelope :: (Fractional n, Metric v) => Point v n -> Envelope v n
 pointEnvelope p = moveTo p (mkEnvelope $ const 0)
 
@@ -217,8 +225,8 @@ through t will no longer be perpendicular to v.
 
 However, it turns out that if v and w are perpendicular, then t^-1 v
 will be perpendicular to t^T w, that is, the *transpose* of t (when
-considered as a matrix) applied to w.  The proof is simple: if vand w
-are perpendicular then v . w = v^T w = 0.  Thus,
+considered as a matrix) applied to w.  The proof is simple. Recall
+that v and w are perpendicular if and only if v . w = v^T w = 0.  Thus,
 
   (t^-1 v) . (t^T w) = (t^-1 v)^T (t^T w) = v^T t^-T t^T w = v^T w = 0.
 
@@ -350,6 +358,7 @@ radius v = (0.5*) . diameter v
 extent :: (V a ~ v, N a ~ n, Enveloped a) => v n -> a -> Maybe (n, n)
 extent v a = (\f -> (-f (negated v), f v)) <$> (appEnvelope . getEnvelope $ a)
 
--- | The smallest positive vector that bounds the envelope of an object.
+-- | The smallest positive /axis-parallel/ vector that bounds the
+--   envelope of an object.
 size :: (V a ~ v, N a ~ n, Enveloped a, HasBasis v) => a -> v n
 size d = tabulate $ \(E l) -> diameter (zero & l .~ 1) d
